/*

    Zelda Oni Link Begins

    Copyright (C) 2006-2008  Vincent Jouillat

    Please send bugreports with examples or suggestions to www.zeldaroth.fr

*/

#include <sstream>
#include <fstream>
#include <iostream>

#include <SDL/SDL.h>

#include "Audio.h"

Audio::Audio() : volume(0), volson(0), musiqueId(0), specialId(0), music(0) {
    
    FMOD_RESULT mainresult;
    
    mainresult = FMOD_System_Create(&sys);      // Create the main system object. 
    if (mainresult != FMOD_OK) SOUND = false;
    
    if (SOUND) {
        mainresult = FMOD_System_Init(sys,100, FMOD_INIT_NORMAL, 0);   // Initialize FMOD. 
        if (mainresult == FMOD_ERR_OUTPUT_CREATEBUFFER) { 
            FMOD_System_SetSpeakerMode(sys,FMOD_SPEAKERMODE_STEREO); 
            mainresult = FMOD_System_Init(sys,100, FMOD_INIT_NORMAL, 0); 
        } 
        if (mainresult != FMOD_OK) SOUND = false;
    }
    
    if (SOUND) loadSounds();
}

Audio::~Audio() {
    if (SOUND) {
        freeSounds();
        FMOD_Sound_Release(music);
        FMOD_System_Close(sys); 
        FMOD_System_Release(sys);
    }
}

void Audio::setVolume(int vol) {
    volume=(vol*4.0)/256.0;
    if (SOUND) FMOD_Channel_SetVolume(channelMusic, volume);
}

void Audio::setVolson(int vol) {volson=(vol*4.0)/256.0;}

void Audio::loadSounds() {
    sons = new FMOD_SOUND*[44];
    
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/text.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[0]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/menu1.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[1]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/menu2.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[2]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/menu3.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[3]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/menu4.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[4]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/timewarp.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[5]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/tombe.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[6]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/hitenemy.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[7]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/killenemy.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[8]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/surprise.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[9]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/monte.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[10]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/descend.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[11]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/chute.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[12]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/item.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[13]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/rupee.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[14]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/heart.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[15]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/bomb.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[16]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/textnext.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[17]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/textend.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[18]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/happy.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[19]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/door.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[20]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/pics.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[21]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/sword.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[22]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/SwordCharging.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[23]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/Sword360.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[24]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/shoot.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[25]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/hookshot.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[26]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/stamp.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[27]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/magic.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[28]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/burn.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[29]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/hammer.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[30]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/plouf.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[31]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/danger.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[32]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/hurt.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[33]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/porte.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[34]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/lance.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[35]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/casse.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[36]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/charge.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[37]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/buisson.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[38]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/pousse.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[39]);
    FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/envol.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[40]);
	FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/vide.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[41]);
	FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/masque.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[42]);
	FMOD_System_CreateSound(sys, (getPath() + "/Contents/Resources/data/sound/splash.ogg").c_str(), FMOD_HARDWARE | FMOD_LOOP_OFF | FMOD_2D, 0, &sons[43]);
}

void Audio::freeSounds() {
    if (SOUND) {
        for (int i = 0; i < 44; i++) FMOD_Sound_Release(sons[i]);
        delete[] sons;
    }
}

void Audio::playSound(int id, int chl) {
    if (SOUND) {
        FMOD_System_PlaySound(sys, (FMOD_CHANNELINDEX)chl, sons[id], 0, &channelSound);
        FMOD_Channel_SetVolume(channelSound, volson);
        FMOD_System_Update(sys);
    }
}

void Audio::playMusic(int id) {
    if (SOUND) {
        if (musiqueId != id) {
            musiqueId = id;            
            if (specialId == 0) {
                FMOD_Channel_SetPaused(channelMusic, true);
                FMOD_Sound_Release(music);
                choixMusique(id);
                FMOD_System_PlaySound(sys, (FMOD_CHANNELINDEX)0, music, 0, &channelMusic);
                FMOD_Channel_SetVolume(channelMusic, volume);
                specialId = 0;
            }
        }
    }
}

bool Audio::isSpecial() {return (specialId>0);}

void Audio::stopMusic() {
    if (SOUND) FMOD_Channel_SetPaused(channelMusic, true);
}

void Audio::replayMusic() {
    if (SOUND) FMOD_Channel_SetPaused(channelMusic, false);
}

void Audio::choixMusique(int id) {
    switch (id) {
		case 1 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Foret.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 2 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Plaine.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 3 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Villageest.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 4 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Vallee.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 5 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Desert.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 6 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Lac.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 7 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Rauru.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 8 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Chateau.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 9 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/PlaineO.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 10 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Marais.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 11 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Ombre.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 12 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Secret.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 13 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Mido.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 14 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Mont.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 15 : case 17 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Donjon1.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 18 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Manoir.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 19 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Ordinn.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 20 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Colisee.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 21 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Lanelle.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 22 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/DFinal.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 23 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/DDesert.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 24 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Glace.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 25 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Farore.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 26 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Xanto.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 27 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/DSecret.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 28 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/TourD.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 16 : case 29 : case 31 : case 32 : case 33 : case 34 : case 35 :
        case 36 : case 37 : case 38 : case 40 : case 41 : case 42 : case 43 :
            FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Cave.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 30 : case 39 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Fee.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 44 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Pit.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 45 : case 46 : case 54 : case 57 : case 58 : case 63 : case 64 :
        case 66 : case 67 : case 71 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Maison.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 52 : case 56 : case 61 : case 70 :
            FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Potion.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 48 : case 53 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Bar.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 49 : case 62 : case 68 : case 79 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Maire.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 50 : case 51 : case 59 : case 60 : case 65 : case 69 :
            FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Magasin.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 47 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Jeu.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 55 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Triste.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 80 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Titre.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 90 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Selection.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 100 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Debut.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        default : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Maison.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
    }
}

void Audio::playSpecial(int id) {
    if (SOUND) {
        if (specialId != id) {
            FMOD_Channel_SetPaused(channelMusic, true);
            FMOD_Sound_Release(music);
            choixSpecial(id);
            FMOD_System_PlaySound(sys, (FMOD_CHANNELINDEX)0, music, 0, &channelMusic);
            FMOD_Channel_SetVolume(channelMusic, volume);
            specialId = id;
        }    
    }
}

void Audio::stopSpecial() {
    if (!specialId) return;
    int tmp = musiqueId;
    musiqueId = 0;
    specialId = 0;
    playMusic(tmp);
}

void Audio::choixSpecial(int id) {
    switch (id) {
        case 1 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Boss.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 2 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Mort.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 3 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Epee.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 4 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/BossF.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        case 5 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Fin.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
		case 6 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/BossM.mid").c_str(),
 FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
		case 7 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Area81.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
		case 8 : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/OniLink.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
        default : FMOD_System_CreateStream(sys, (getPath() + "/Contents/Resources/data/music/Boss.mid").c_str(), FMOD_HARDWARE | FMOD_LOOP_NORMAL | FMOD_2D, 0, &music); return;
    }
}

